import React, { useState } from 'react';
import { Button, Row, Col, Input, InputNumber, notification } from 'antd';
import XForm, { FieldTypes } from '../../../components/XForm';
import Style from '../style.less';
import { fetch, apis } from '../../../utils/request';

const saveMiniapp = fetch(apis.member.miniapp);

const TplItem = React.forwardRef((props, ref) => {
  const [val, setVal] = useState({
    tplId: undefined,
    fieldNum: undefined,
    ...props.value || {}
  })

  const handleChange = field => e => {
    const newVal = { ...val, [`${field}`]: (e.target ? e.target.value : e) }
    setVal(newVal)

    if (typeof props.onChange === 'function') {
      props.onChange(newVal)
    }
  }

  return (
    <Input.Group compact ref={ref}>
      <Input style={{ width: '70%' }} value={val.tplId} placeholder="消息模板ID" onChange={handleChange('tplId')}></Input>
      <InputNumber style={{ width: '30%' }} value={val.fieldNum} placeholder="字段数" onChange={handleChange('fieldNum')}></InputNumber>
    </Input.Group>
  );
})

const Miniapp = (props) => {
  const user = props.data || {}
  const appdata = user.miniapp || {};
  const noticeTPL = (appdata.tpls || []).filter(x => x.tplType === 'notice')[0] || {}

  const checkMiniapp = () => {
  }

  const fields = [
    {
      label: '名称',
      name: 'name',
      type: FieldTypes.Text,
      value: appdata.name,
      rules: [{required: true, message: '请填写小程序名称'}]
    },
    {
      label: 'APPID',
      name: 'miniappId',
      type: FieldTypes.Text,
      value: appdata.miniappId,
      rules: [
        { required: true, message: '请填写 APPID' },
        { pattern: /^[a-zA-Z0-9]+$/, message: 'APPID 只能由字母与数字组成' }
      ]
    },
    {
      label: 'Secret',
      name: 'secret',
      type: FieldTypes.Text,
      value: appdata.secret,
      rules: [
        { required: true, message: '请填写 Secret' },
        { pattern: /^[a-zA-Z0-9]+$/, message: 'APPID 只能由字母与数字组成' }
      ]
    },
    {
      label: 'Token',
      name: 'token',
      value: appdata.token,
      type: FieldTypes.Text,
      rules: [
        { pattern: /^[a-zA-Z0-9]+$/, message: 'token 只能由字母与数字组成' }
      ]
    },
    {
      label: 'AES_KEY',
      name: 'aesKey',
      value: appdata.aesKey,
      type: FieldTypes.Text,
      rules: [
        { pattern: /^[a-zA-Z0-9]+$/, message: 'AES_KEY 只能由字母与数字组成' }
      ]
    },
    // {
    //   label: '业务受理',
    //   name: 'mainbiz',
    //   render: <TplItem />
    // },
    // {
    //   label: '新客户通知',
    //   name: 'newCustomer',
    //   render: <TplItem />
    // },
    {
      label: '消息通知',
      name: 'notice',
      render: () => <TplItem />,
      value: noticeTPL,
    },
    {
      action: true,
      render: () => {
        return (
          <div className={Style['flex-box']}>
            <div className={Style['flex-item']}>
              <img src="" alt="" style={{ width: '128px' }}/>
            </div>
            <div className={Style['flex-auto']}>
              <Button type="primary" ghost onClick={checkMiniapp}>验证</Button>
            </div>
          </div>
        )
      }
    },
  ]

  const handleSubmit = val => {
    // 校验字段
    const { mainbiz, newCustomer, notice, ...otherData} = val

    // if (mainbiz.tplId && !mainbiz.fieldNum) {
    //   notification.error({ message: '请填写业务受理消息模板字段数' })
    //   return
    // }
    
    // if (newCustomer.tplId && !newCustomer.fieldNum) {
    //   notification.error({ message: '请填写新客户通知模板字段数' })
    //   return
    // }
    
    if (notice.tplId && !notice.fieldNum) {
      notification.error({ message: '请填写消息通知模板字段数' })
      return
    }

    const tpls = [
      {
        ...notice,
        ...(appdata.tpls || []).filter(x => x.tplType === 'notice')[0] || {},
        tplType: 'notice'
      }
    ]

    const data = {
      ...appdata,
      ...otherData,
      orgId: user.orgId,
      tpls,
    }

    saveMiniapp({ data }).then(() => {
      notification.success({ message: '保存小程序信息成功' })
    }).catch(x => x)
  }

  const handleCancel = () => {
    if (typeof props.onCancel === 'function') {
      props.onCancel()
    }
  }

  return (<XForm onSubmit={handleSubmit} onCancel={handleCancel} fields={fields}></XForm>)
}

export default Miniapp;
