import React, { useState, useEffect } from 'react';
import { Button, notification } from 'antd';
import md5 from 'md5';
import moment from 'moment';
import router from 'umi/router';
import XForm, { FieldTypes } from '../../../components/XForm';
import { fetch, apis } from '../../../utils/request';

const defaultPass = '123456';
const saveUser = fetch(apis.member.save)
const updateUser = fetch(apis.member.update)

export default (props) => {
  const [data, setData] = useState({})
  const [submitting, setSubmitting] = useState(false)
  const user = props.data;

  const fields = [
    {
      label: '公司名称',
      name: 'orgName',
      type: FieldTypes.Text,
      value: user.orgName,
    },
    {
      label: '公司水印',
      name: 'waterMark',
      type: FieldTypes.ImageUploader,
      value: user.waterMark,
    },
    {
      label: '用户名称',
      name: 'userName',
      type: FieldTypes.Text,
      rules: [
        {required: true, message: '请填写用户名称'}
      ],
      value: user.userName,
    },
    {
      label: '手机号',
      name: 'phone',
      type: FieldTypes.Text,
      rules: [
        {required: true, message: '请填写手机号'},
        {len: 11, message: '手机号格式不正确'}
      ],
      value: user.phone,
    },
    {
      label: '登录名称',
      name: 'loginName',
      type: FieldTypes.Text,
      placeholder: '不填, 默认使用手机号',
      extra: `默认登录密码 ${defaultPass}`,
      value: user.loginName,
    },
    {
      label: '头像',
      name: 'avatar',
      type: FieldTypes.ImageUploader,
      extra: '建议图片大小 128 * 128',
      value: user.avatar,
    },
    {
      label: '有效期',
      name: 'expDate',
      type: FieldTypes.DatePicker,
      rules: [
        {required: true, message: '请选择有效期'}
      ],
      value: moment(user.expDate),
    },
  ]

  const handleSubmit = val => {
    const data = {
      ...val,
      loginName: val.loginName || val.phone,
      loginPassword: md5(defaultPass),
    }

    setSubmitting(true)
    if (user && user.userId) {
      updateUser({ urlData: { id: user.userId }, data: { ...user, ...data } }).then((user) => {
        setSubmitting(false)
        notification.success({message: '编辑信息成功'})
      }).catch(() => setSubmitting(false))
    } else {
      saveUser({ data }).then((user) => {
        setSubmitting(false)
        notification.success({message: '新建信息成功'})
      }).catch(() => setSubmitting(false))
      router.push(`/member/edit/${user.userId}`)
    }
  }

  const handleCancel = () => {
    if (typeof props.onCancel === 'function') {
      props.onCancel()
    }
  }

  return (<XForm onSubmit={handleSubmit} onCancel={handleCancel} fields={fields} submitting={submitting}></XForm>)
}
